# -*- coding: utf-8 -*-
import sys, json
from bs4 import BeautifulSoup
try:
    from urllib2 import urlopen
except ImportError:
    from urllib.request import urlopen
try:
    from urlparse import urlparse, urljoin
except ImportError:
    from urllib.parse import urlparse, urljoin
try:
    from urllib import urlencode, quote
except ImportError:
    from urllib.parse import urlencode, quote


def getsoup(url):
    if (2, 7, 3) <= sys.version_info < (3, 0) or (3, 2) <= sys.version_info < (4, 0):
        return BeautifulSoup(urlopen(url), 'html.parser')
    return BeautifulSoup(urlopen(url), 'html5lib')


def getjson(url, data=None):
    return json.loads(urlopen(url, data).read().decode('utf-8-sig'))


def category(cat, page=1):
    url = 'http://www.haitum.com/%s/page/%d' % (cat, page)
    try:
        soup = getsoup(url)
    except Exception as e:
        return {'code': 'haitum 200', 'error': str(e)}
    ret = []
    try:
        for e1 in soup.find('ul', {'class': 'new-list'})('li'):
            e2 = e1.a
            if not e2:
                continue
            if 'href' not in e2.attrs:
                continue
            title = e2.div.p.text
            e3 = e2.span
            if e3:
                title += ' ' + e3.text
            ret.append({'title': title, 'url': urljoin(url, e2['href'])})
    except Exception as e:
        return {'code': 'haitum 201', 'error': str(e)}
    ret.append({'title': 'Next Page', 'category': cat, 'page': page + 1})
    return ret


def search(s, page=1):
    if not s:
        return {'code': 'haitum 300'}
    url = 'http://www.haitum.com/search/%s/page/%d' % (quote(s), page)
    try:
        soup = getsoup(url)
    except Exception as e:
        return {'code': 'haitum 301', 'error': str(e)}
    ret = []
    try:
        for e1 in soup.find('ul', {'class': 'search-list'})('li'):
            e2 = e1.h5
            if not e2:
                continue
            e3 = e2.a
            if not e3:
                continue
            if 'href' not in e3.attrs:
                continue
            ret.append({'title': e3.text, 'url': urljoin(url, e3['href'])})
    except Exception as e:
        return {'code': 'haitum 302', 'error': str(e)}
    if page < int(soup.find('div', {'class': 'count'}).b.text):
        ret.append({'title': 'Next Page', 'search': s, 'page': page + 1})
    return ret


def movie(url, index=-1):
    ret = []
    if index == -1:
        try:
            soup = getsoup(url)
        except Exception as e:
            return {'code': 'haitum 101', 'error': str(e)}
        try:
            i = -1
            for e1 in soup.find('ul', {'class': 'nav-tabs'})('li'):
                i += 1
                e2 = e1.a
                if not e2:
                    continue
                title = e2.text
                if 'title' in e2.attrs:
                    title += ' ' + e2['title']
                ret.append({'title': title, 'url': url, 'index': i})
        except Exception as e:
            return {'code': 'haitum 102', 'error': str(e)}
        return ret
    o = urlparse(url)
    p = o.path.split('/')
    assert p[2]
    if p[2][-5:] != '.html':
        return {'code': 'haitum 100'}
    p[2] = p[2][:-5]
    data = {
        'order': 'getTargetRsBoxData',
        'ids': p[2],
        'type': 0,
        'index': index
    }
    try:
        data = getjson('http://www.haitum.com/common/api_getTargetRsBoxData.php', urlencode(data))
    except Exception as e:
        return {'code': 'haitum 111', 'error': str(e)}
    try:
        for e in data['data']['episodes']:
            ret.append({'title': data['data']['provider'] + ' ' + e['title'], 'url': e['url']})
    except Exception as e:
        return {'code': 'haitum 112', 'error': str(e)}
    return ret
    # o = urlparse(url)
    # p = o.path.split('/')
    # assert p[2]
    # if p[2][-5:] != '.html':
    #     return {'code': 'haitum 100'}
    # p[2] = p[2][:-5]
    # p[2] = p[2].split('-')
    # if len(p[2]) != 2:
    #     return {'code': 'haitum 101'}
    # data = {
    #     'order': 'getNewHost',
    #     'aid': '',
    #     'sid': p[2][0],
    #     'mid': p[2][1],
    #     'isstatic': 1,
    #     'target': 'movieDetails',
    #     'rp0': index,
    #     'rp1': 0,
    #     'isBackServerRsData': 1
    # }
    # try:
    #     data = getjson('http://www.haitum.com/common/api_getNewHost.php', urlencode(data))
    # except Exception as e:
    #     return {'code': 'haitum 102', 'error': str(e)}
    # try:
    #     for e in data['data']['resource']['episodes']:
    #         ret.append({'title': e['title'], 'url': e['url']})
    # except:
    #     return {'code': 'haitum 103'}
    # return ret
